@@ -12,7 +12,8 @@ require AutoLoader;
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
+@EXPORT = qw
+(
 	PVM_BYTE
 	PVM_CPLX
 	PVM_DCPLX
@@ -93,26 +94,32 @@ require AutoLoader;
 	PvmTraceTid
 );
 
-$VERSION = '1.0';
+$VERSION = '1.2.1';
 
-sub AUTOLOAD {
+sub AUTOLOAD 
+{
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.  If a constant is not found then control is passed
     # to the AUTOLOAD in AutoLoader.
 
     my $constname;
     ($constname = $AUTOLOAD) =~ s/.*:://;
+    croak "& not defined" if $constname eq 'constant';
     my $val = constant($constname, @_ ? $_[0] : 0);
-    if ($! != 0) {
-	if ($! =~ /Invalid/) {
+    if ($! != 0) 
+    {
+	if ($! =~ /Invalid/) 
+        {
 	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
 	    goto &AutoLoader::AUTOLOAD;
 	}
-	else {
+	else 
+        {
 		croak "Your vendor has not defined Parallel::Pvm macro $constname";
 	}
     }
-    eval "sub $AUTOLOAD { $val }";
+    no strict 'refs';
+    *$AUTOLOAD = sub () { $val };
     goto &$AUTOLOAD;
 }
 
@@ -348,7 +355,7 @@ the problem.  Eg.
 For more sophisticated users, B<Parallel::Pvm::spawn> may be given additional 
 argument parameters to control how/where you want a task to be spawned.
 For example, you can specifically spawn B<client> in the internet 
-host <onyx.nsrc.nus.sg> by calling
+host B<onyx.nsrc.nus.sg> by calling
 
 	Parallel::Pvm::spawn("client",1,PvmTaskHost,"onyx.nsrc.nus.sg");
 
@@ -357,6 +364,11 @@ say RS6K workstations, by calling
 
 	Parallel::Pvm::spawn("client",4,PvmTaskArch,"RS6K");
 
+Also, if the spawned remote executable requires an argument B<argv>, 
+you can supply this by calling
+
+	Parallel::Pvm::spawn("client",4,PvmTaskArch,"RS6K",argv);
+
 Note that tasks which have been spawned by using B<Parallel::Pvm::spawn> 
 do not need to be explicitly enrolled into the pvm system.  
 
@@ -662,6 +674,12 @@ Requests notification of PVM events. Eg.
 
 	$info = Parallel::Pvm::notify(PvmHostDelete,999,$host_list);
 
+	# turns on notification for new host
+	$info = Parallel::Pvm::notify(PvmHostAdd);
+
+        # turns off notification for new host
+	$info = Parallel::Pvm::notify(PvmHostAdd,0);
+
 =item B<Parallel::Pvm::nrecv>
 
 Nonblocking receive.  Eg.
@@ -753,10 +771,14 @@ Redefines the comparison function used to accept messages.  Eg.
 Receives the notification message initiated by B<Parallel::Pvm::notify>.  This 
 should be preceded by a B<Parallel::Pvm::probe>.  Eg.
 
+	# for PvmTaskExit and PvmHostDelete notification
 	if ( Parallel::Pvm::probe(-1,$notify_tag) ){
-		$message = Parallel::Pvm::recv_notify ;
+		$message = Parallel::Pvm::recv_notify(PvmTaskExit) ;
 	}
 
+	# for PvmHostAdd notification
+	@htid_list = Parallel::Pvm::recv_notify(PvmHostAdd);
+
 =item B<Parallel::Pvm::recvf_old>
 
 Resets the comparison function for accepting messages to the 
@@ -830,6 +852,8 @@ Starts new PVM processes.  Eg.
 
 	($ntask,@tid_list) = Parallel::Pvm::spawn("compute.pl",4,PvmTaskHost,"onyx");
 
+	($ntask,@tid_list) = Parallel::Pvm::spawn("compute.pl",4,PvmTaskHost,"onyx",argv);
+
 =item B<Parallel::Pvm::tasks>
 
 Returns information about the tasks running on the virtual machine. Eg.
@@ -866,11 +890,13 @@ Unpacks the active receive message buffer.  Eg.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Edward Walker, edward@nsrc.nus.sg,
 National Supercomputing Research Centre, Singapore
 
+Denis Leconte, denis_leconte@geocities.com 
+
 =head1 SEE ALSO
 
 perl(1), pvm_intro(1PVM)
